<?php

// Include necessary files and start session
require_once 'config/access.php';
require_once 'include/functions.php';
start_session();

// Check if the user is authenticated (simple check; expand as needed)
if (!is_logged_in()) {
    echo json_encode(['error' => 'Unauthorized access.']);
    http_response_code(401);
    exit();
}

// Validate CSRF token if applicable
if ($_SERVER['REQUEST_METHOD'] === 'POST' && !verify_csrf_token(post('csrf_token'))) {
    echo json_encode(['error' => 'Invalid CSRF token.']);
    http_response_code(403);
    exit();
}

// Initialize response array
$response = ['status' => 'error', 'message' => 'Unknown request'];

// Determine the action to take based on the 'action' parameter
$action = post('action') ?? get('action');

switch ($action) {
    case 'get_users':
        // Function to get users from the database
        $response = get_users();
        break;

    case 'add_user':
        // Function to add a user, using sanitized input
        $username = sanitize_input($conn, post('username'));
        $email = sanitize_input($conn, post('email'));
        $password = hash_password(post('password'));
        $response = add_user($username, $email, $password);
        break;

    // Add more cases for different actions

    default:
        $response['message'] = 'Invalid request';
        break;
}

// Send the JSON response
header('Content-Type: application/json');
echo json_encode($response);

/**
 * Function to get users from the database
 *
 * @return array JSON encoded list of users
 */
function get_users() {
    global $conn;
    $query = "SELECT id, username, email FROM users";
    $result = $conn->query($query);
    
    if ($result) {
        $users = [];
        while ($row = $result->fetch_assoc()) {
            $users[] = $row;
        }
        return ['status' => 'success', 'data' => $users];
    } else {
        return ['status' => 'error', 'message' => 'Failed to fetch users'];
    }
}

/**
 * Function to add a user to the database
 *
 * @param string $username
 * @param string $email
 * @param string $password
 * @return array JSON encoded success or error message
 */
function add_user($username, $email, $password) {
    global $conn;
    $query = "INSERT INTO users (username, email, password) VALUES ('$username', '$email', '$password')";
    if ($conn->query($query)) {
        return ['status' => 'success', 'message' => 'User added successfully'];
    } else {
        return ['status' => 'error', 'message' => 'Failed to add user: ' . $conn->error];
    }
}

/**
 * Verify the CSRF token
 *
 * @param string $token
 * @return bool
 */
function verify_csrf_token($token) {
    return isset($_SESSION['csrf_token']) && $_SESSION['csrf_token'] === $token;
}
?>
